@@ -7,19 +7,31 @@ use Class::C3;
 sub process {
     my $self = shift;
 
-    my @set = map { $_->{value} } @{ $self->parent->_options };
+    my @set = map { _parse_value($_) } @{ $self->parent->_options };
+    
     $self->set( \@set );
 
     return $self->next::method(@_);
 }
 
+sub _parse_value {
+    my ($item) = @_;
+    
+    if ( exists $item->{group} ){
+        return map { _parse_value($_) } @{ $item->{group} }
+    }
+    else {
+        return $item->{value};
+    }
+}
+
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Constraint::AutoSet
+HTML::FormFu::Constraint::AutoSet - Set Constraint for Selects / Radiogroups
 
 =head1 DESCRIPTION
 
