@@ -3,11 +3,6 @@ package HTML::FormFu::Constraint::Equal;
 use strict;
 use base 'HTML::FormFu::Constraint::_others';
 
-use Exporter qw/ import /;
-
-# only exported for use by test suite
-our @EXPORT_OK = qw/ _values_eq /;
-
 sub process {
     my ( $self, $params ) = @_;
 
@@ -71,7 +66,7 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::Constraint::Equal
+HTML::FormFu::Constraint::Equal - Multi-field Equality Constraint
 
 =head1 SYNOPSIS
 
