@@ -1,14 +1,13 @@
 package HTML::FormFu::Element;
 
 use strict;
-use base 'Class::Accessor::Chained::Fast';
 use Class::C3;
 
 use HTML::FormFu::Attribute qw/ mk_attrs mk_attr_accessors 
-    mk_output_accessors mk_inherited_accessors
+    mk_output_accessors mk_inherited_accessors mk_accessors 
     mk_inherited_merging_accessors /;
 use HTML::FormFu::ObjectUtil qw/ load_config_file _render_class
-    populate form stash /;
+    populate form stash parent /;
 use HTML::FormFu::Util qw/ require_class xml_escape /;
 use Scalar::Util qw/ refaddr /;
 use Storable qw( dclone );
@@ -27,7 +26,7 @@ __PACKAGE__->mk_attr_accessors(qw/ id /);
 
 __PACKAGE__->mk_accessors(
     qw/
-        parent name type filename multi_filename is_field
+        name type filename multi_filename is_field
         render_class_suffix /
 );
 
@@ -49,6 +48,10 @@ sub new {
 
     $self->attributes( {} );
     $self->stash(      {} );
+    
+    if ( exists $attrs{parent} ) {
+        $self->parent( delete $attrs{parent} );
+    }
 
     $self->populate( \%attrs );
 
@@ -133,9 +136,10 @@ sub render {
             multi_filename      => $self->multi_filename,
             is_field            => $self->is_field,
             stash               => $self->stash,
-            parent              => $self,
             @_ ? %{ $_[0] } : () } );
 
+    $render->parent($self);
+
     $self->prepare_id($render);
 
     $self->prepare_attrs($render);
@@ -155,22 +159,22 @@ HTML::FormFu::Element - Element Base Class
 
     ---
     elements:
-      - type: text
+      - type: Text
         name: username
         constraints:
           - type: Required
       
-      - type: password
+      - type: Password
         name: password
         constraints:
           - type: Required
           - type: Equal
             others: repeat-password
       
-      - type: password
+      - type: Password
         name: repeat-password
       
-      - type: submit
+      - type: Submit
 
 =head1 DESCRIPTION
 
